@@ -37,8 +37,10 @@ void flatpak_exports_free (FlatpakExports *exports);
 FlatpakExports *flatpak_exports_new (void);
 void flatpak_exports_append_bwrap_args (FlatpakExports *exports,
                                         FlatpakBwrap   *bwrap);
-void flatpak_exports_add_host_expose (FlatpakExports       *exports,
-                                      FlatpakFilesystemMode mode);
+void flatpak_exports_add_host_etc_expose (FlatpakExports       *exports,
+                                          FlatpakFilesystemMode mode);
+void flatpak_exports_add_host_os_expose (FlatpakExports       *exports,
+                                         FlatpakFilesystemMode mode);
 void flatpak_exports_add_path_expose (FlatpakExports       *exports,
                                       FlatpakFilesystemMode mode,
                                       const char           *path);
